import { Line, Town, Route, Parada, PasoTime, Horario, VehiclePosition, Vehicle } from './data/models';
declare type Options = {
    timeout?: number;
};
declare class BizkaibusService {
    private towns;
    private services;
    /**
     * Creates an instance of BizkaibusService.
     * @param {Options} [options]
     * @memberof BizkaibusService
     */
    constructor(options?: Options);
    changeTimeout(timeout: number): Promise<void>;
    /**
     * @param {string} originTown
     * @param {string} destinationTown
     * @returns {Promise<Line[]>}
     * @memberof BizkaibusService
     */
    getFromTo(originTown: string, destinationTown: string): Promise<Line[]>;
    /**
     * @param {(string | Line)} line
     * @param {Date} [date]
     * @returns {Promise<Horario>}
     * @memberof BizkaibusService
     */
    getHorario(line: string | Line, date?: Date): Promise<Horario>;
    /**
     * @method getPdf
     * @param {(string | Line)} line
     * @param {('I' | 'V')} [direction]
     * @returns
     * @memberof BizkaibusService
     */
    getPdf(line: string | Line, direction?: 'I' | 'V'): Promise<any>;
    /**
     * Obtiene un listado de paradas a partir de una línea y una ruta determinadas
     * @param {Line} linea
     * @param {Route} route
     * @returns {Promise<Parada[]>}
     * @memberof BizkaibusService
     */
    getItinerario(linea: Line, route: Route): Promise<Parada[]>;
    /**
     * Obtiene un listado de paradas del pueblo seleccionado
     * @param {string} town
     * @returns {Promise<Parada[]>}
     * @memberof BizkaibusService
     */
    getParadasTown(town: string): Promise<Parada[]>;
    /**
     * @param {Parada} parada
     * @returns {Promise<PasoTime[]>}
     * @memberof BizkaibusService
     */
    getPasoParada(parada: Parada): Promise<PasoTime[]>;
    /**
     * @param {string} line
     * @returns {Promise<Line>}
     * @memberof BizkaibusService
     */
    getLineInfo(line: string): Promise<Line>;
    /**
     * @param {(string | Line)} line
     * @returns {Promise<VehiclePosition[]>}
     * @memberof BizkaibusService
     */
    getVehicles(line: string | Line): Promise<VehiclePosition[]>;
    /**
     * @returns {Promise<Line[]>}
     * @memberof BizkaibusService
     */
    getLines(): Promise<Line[]>;
    /**
     * @param {VehiclePosition} vehiclePosition
     * @returns {Promise<Vehicle>}
     * @memberof BizkaibusService
     */
    getBusInfo(vehiclePosition: VehiclePosition): Promise<Vehicle>;
    /**
     * Devuelve el listado de pueblos guardado en el servicio
     * En caso de necesitar actualizarlos llamar al método updateTowns
     * @returns {Promise<Town[]>}
     * @memberof BizkaibusService
     */
    getTowns(): Promise<Town[]>;
    /**
     * @returns
     * @memberof BizkaibusService
     */
    updateTowns(): Promise<Town[]>;
}
export = BizkaibusService;
